==> motd1.0.2.tar.gz: motd/motd.tcl <==
# Motd 1.0.2 by Corbe 
# BotName: corbe@devilbot
#   Email: corbe@laker.net

# Notes:
#   1.0: I'm a very shortcutsy kind of guy which means this script
#        requires includes. EG toolkit.tcl and toolbox.tcl 

# ChangeLog:
#   1.0.1: Fixed some spelling mistakes
#   1.0.1: Fixed the !nogreet !yesgreet message. Works now.
#   1.0.1: Fixed some sloppy code
#   1.0.1: Fixed the problem with the bot showing itself the motd *grin*
#   1.0.2: Ported for Eggdrop 1.1(.5). I think 1.2.0 sucks so there will be
#          no support for that release.
#   1.0.2: Added CTCP VERSION support because this is the only script that
#          I have made that does not support a ctcp version reply.

source scripts/motd/settings.tcl
source scripts/motd/bindings.tcl
source scripts/motd/config.tcl

if {![info exists toolbox_loaded]} {
  putlog "motd: Warning: serverside include: toolbox.tcl not loaded.
  source ../toolbox.tcl
  if {![info exists toolbox_loaded]} {
    putlog "motd: Error: serverside include: toolbox.tcl not found.
    die "motd: Error while trying to load script"
  }
} else {
  if {$toolbox_revision < "1004"} {
    putlog "motd: Warning: Toolbox is obsolete. Please upgrade to revision 1004 or later."
  }
}

if {![info exists toolkit_loaded]} {
  putlog "motd: Warning: serverside include: toolkit.tcl not loaded.
  source ../toolkit.tcl
  if {![info exists toolkit_loaded]} {
    putlog "motd: Error: serverside include: toolkit.tcl not found.
    die "motd: Error while trying to load script"
  }
} 

# This statement is sloppy as hell but it works, It needs to be cleaned up
proc do_show_motd {nick uhost hand channel} {
  global motdpath wantgflag botnick
  if {$nick == $botnick} {
    return 0
  } else {
  set fd [open $motdpath r]
  if {[validuser $hand] == "1"} {
    if {[matchattr $hand g] == 0} {
      if {$wantgflag == "1"} {
        while {![eof $fd]} {
          set motdinfo [gets $fd]
          putmsg $nick "-=- $motdinfo"
        }
        putmsg $nick "You can turn this message off by typing !NOGREET in the channel"
        putmsg $nick "You can turn it on again by typing !YESGREET"
        close $fd
      } else {
        while {![eof $fd]} {
          set motdinfo [gets $fd]
          putmsg $nick "-=- $motdinfo"
        }
        close $fd
      }     
    }
  } else {
    if {$wantgflag == "1"} {
      while {![eof $fd]} {
        set motdinfo [gets $fd]
        putmsg $nick "-=- $motdinfo"
      }
      close $fd
      putmsg $nick "I also noticed you are not a user on this bot."
      putmsg $nick "if you would like to become a user please type"
      putmsg $nick "/msg $botnick $myword"    
    }
  }
}
# Can anyone tell me where I'm missing a close brace?
}

if {$cpuawarness == "1" && $wantgflag == "0"} {
} else {
  proc do_no_greet {nick uhost hand channel arg} {
    global wantgflag botnick 
    if {[validuser $hand] == "1"} {
      if {[matchattr $hand g] != "1"} {
        putmsg $nick "You will no longer recieve automated greets"
        chattr $hand +g
      } else {
         putmsg $nick "You already have automated greets OFF!"
      }
    } else {
      putmsg $nick "You are not a user on this bot! please /msg $botnick hello"
    }
  }
}

if {$cpuawarness == "1" && $wantgflag == "0"} {
} else {
  proc do_yes_greet {nick uhost hand channel arg} {
    global wantgflag botnick 
    if {[validuser $hand] == "1"} {
      if {[matchattr $hand g] == "1"} {
        putmsg $nick "You will now recieve automated greets"
        chattr $hand -g
      } else {
         putmsg $nick "You already have automated greets ON!"
      }
    }
  }
}

putlog "MOTD 1.0.2 by Corbe Successfully Loaded"
putlog "Mail corbe@shadow.net with questions/comments"

==> motd1.0.3.tar.gz: motd/motd.tcl <==
# Motd 1.0.3 by Corbe 
# BotName: corbe@devilbot
#   Email: corbe@laker.net

# Notes:
#   1.0: I'm a very shortcutsy kind of guy which means this script
#        requires includes. EG toolkit.tcl and toolbox.tcl 

# ChangeLog:
#   1.0.1: Fixed some spelling mistakes
#   1.0.1: Fixed the !nogreet !yesgreet message. Works now.
#   1.0.1: Fixed some sloppy code
#   1.0.1: Fixed the problem with the bot showing itself the motd *grin*
#   1.0.2: Ported for Eggdrop 1.1(.5). I think 1.2.0 sucks so there will be
#          no support for that release.
#   1.0.2: Added CTCP VERSION support because this is the only script that
#          I have made that does not support a ctcp version reply.
#   1.0.3: Fixed the problem with the hello binding -- OOPS =)

source scripts/motd/settings.tcl
source scripts/motd/bindings.tcl
source scripts/motd/config.tcl

if {![info exists toolbox_loaded]} {
  putlog "motd: Warning: serverside include: toolbox.tcl not loaded.
  source ../toolbox.tcl
  if {![info exists toolbox_loaded]} {
    putlog "motd: Error: serverside include: toolbox.tcl not found.
    die "motd: Error while trying to load script"
  }
} else {
  if {$toolbox_revision < "1004"} {
    putlog "motd: Warning: Toolbox is obsolete. Please upgrade to revision 1004 or later."
  }
}

if {![info exists toolkit_loaded]} {
  putlog "motd: Warning: serverside include: toolkit.tcl not loaded.
  source ../toolkit.tcl
  if {![info exists toolkit_loaded]} {
    putlog "motd: Error: serverside include: toolkit.tcl not found.
    die "motd: Error while trying to load script"
  }
} 

# This statement is sloppy as hell but it works, It needs to be cleaned up
proc do_show_motd {nick uhost hand channel} {
  global motdpath wantgflag botnick
  if {$nick == $botnick} {
    return 0
  } else {
  set fd [open $motdpath r]
  if {[validuser $hand] == "1"} {
    if {[matchattr $hand g] == 0} {
      if {$wantgflag == "1"} {
        while {![eof $fd]} {
          set motdinfo [gets $fd]
          putmsg $nick "-=- $motdinfo"
        }
        putmsg $nick "You can turn this message off by typing !NOGREET in the channel"
        putmsg $nick "You can turn it on again by typing !YESGREET"
        close $fd
      } else {
        while {![eof $fd]} {
          set motdinfo [gets $fd]
          putmsg $nick "-=- $motdinfo"
        }
        close $fd
      }     
    }
  } else {
    if {$wantgflag == "1"} {
      while {![eof $fd]} {
        set motdinfo [gets $fd]
        putmsg $nick "-=- $motdinfo"
      }
      close $fd
      putmsg $nick "You can turn this message off by typing !NOGREET in the channel"
      putmsg $nick "You can turn it on again by typing !YESGREET"
      putmsg $nick "I also noticed you are not a user on this bot."
      putmsg $nick "if you would like to become a user please type"
      putmsg $nick "/msg $botnick hello"    
    }
  }
}
# Can anyone tell me where I'm missing a close brace?
}

if {$cpuawarness == "1" && $wantgflag == "0"} {
} else {
  proc do_no_greet {nick uhost hand channel arg} {
    global wantgflag botnick 
    if {[validuser $hand] == "1"} {
      if {[matchattr $hand g] != "1"} {
        putmsg $nick "You will no longer recieve automated greets"
        chattr $hand +g
      } else {
         putmsg $nick "You already have automated greets OFF!"
      }
    } else {
      putmsg $nick "You are not a user on this bot! please /msg $botnick hello"
    }
  }
}

if {$cpuawarness == "1" && $wantgflag == "0"} {
} else {
  proc do_yes_greet {nick uhost hand channel arg} {
    global wantgflag botnick 
    if {[validuser $hand] == "1"} {
      if {[matchattr $hand g] == "1"} {
        putmsg $nick "You will now recieve automated greets"
        chattr $hand -g
      } else {
         putmsg $nick "You already have automated greets ON!"
      }
    }
  }
}

putlog "MOTD 1.0.3 by Corbe Successfully Loaded"
putlog "Mail corbe@laker.net with questions/comments"
